# Examples

- [dataclasses intro](dataclasses/README.md): Quick intro to Python's new [dataclasses](https://docs.python.org/3.7/library/dataclasses.html) module.

- **[Simple example](simple/basic.py)**: Simple use-case example with a before/after comparison.

- [ML-related Examples](ML/README.md)

- **NEW**: [Subgroups Example](subgroups/README.md)

<!-- - **NEW**: [Partials Example](partials/README.md) -->

- [Serialization to `json`/`yaml`](serialization/README.md)

- [Attribute Docstrings Example](docstrings/README.md)

- [Parsing of lists and tuples](container_types/README.md)

- [**Nesting**!!](nesting/README.md)

- [Prefixing](prefixing/README.md)

- [Enums Example](enums/README.md)

- [Subparsers Example](subparsers/README.md)
